## Template: {$ data.metadata.name $}

### Entities

{$ entity.entity.template_id $}

- {$ property $}: {$ value $}

### Relationships

{$ rel.relationship.template_id $}

- {$ property $}: {$ value $}

### Equivalences

- #### Equivalence

  {$ equ.entity.name $}
  - {$ property $}: {$ value $}

### Scenarios

{$ scenario.scenario.condition $}
Actions:

1. - action: {$ action.action.action_type $}
   - {$ key $}: {$ value $}
   - {$ property $}: {$ value $}

                {$ str_data $}